// -*- C++ -*-

/* 
 * GChemPaint library
 * zoomdlg.h
 *
 * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
 * USA
 */

#ifndef GCHEMPAINT_ZOOM_DLG_H
#define GCHEMPAINT_ZOOM_DLG_H

#include <gcu/dialog.h>
#include <gtk/gtkspinbutton.h>

using namespace gcu;

class gcpDocument;

class gcpZoomDlg: public Dialog
{
public:
	gcpZoomDlg (gcpDocument* pDoc);
	virtual ~gcpZoomDlg ();
	
	void OnFocusIn ();
	
private:
	GtkSpinButton *btn;
	gcpDocument *m_Doc;
	gulong m_ZoomSignal;
};

#endif //GCHEMPAINT_ZOOM_DLG_H
